datasets
********


.. toctree::
   :maxdepth: 2

   datasets/rainfall_runoff

   datasets/water_quality

   datasets/laos

   datasets/misc


Datasets
========
.. autoclass:: ai4water.datasets.mtropics.Datasets
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__
